********************************************************************
**											**
**		STATA TUTORIAL	-	IT2011 Alba di Canazei		**
**											**
********************************************************************

*  This do-file is an application of the material covered in class.
*  We make use of a fictitious dataset derived from the 
*  "Panel Socio-conomique 'Liewen zu Letzebuerg' 2003-2008" (PSELL-3).  
*  50 households (hh hereafter) were randomly selected.  
*  To preserve anonimity, the identification number of household/individuals were modified.
*  This teaching dataset accompanies the Winter School Stata Tutorial material
*  and must not be distributed separately 
*  or used for any other purpose.
*  It contains observations on a number of individuals and some limited key variables:
*   	hid 		= household identifier
*	pwgt 		= individual sample weight
* 	Y 		= personal single-adult equivalent income (2005 prices)
*  	natio_hh 	= nationality of the head of the household
*   	age_hh 	= age of the head of the household
*	size 		= number of persons living in the same household 
* -----------------------------------------------------------------------------------
*	Francesco 	Andreoli	(Uni. Verona and ThEMA)
*	Andrea 	Bonfatti	(Uni. Verona)


	
/*----------------	 NOTES 	----------------*/

* Stata reads each line either as a command or a comment.
* *	 	 to write general comments in placed of a command line. 
* //	 	 to write comments immediately after a command (in the same line)
* /* ... */  to put (possibly) many lines as a unique comment without using previous markers.
* ///		 to breack a command, usually written in a single line, in more lines
* To obtain " ` " delimiter, use the numeric keypad of your computer to type the ASCII code (while holding ALT key, type 096).  
* Install the following files by using ssc library, only if connectet to the internet (drop the /*, */ if the ado files are NOT installed)
/*
ssc install estout, replace
ssc install outreg, replace
ssc install svmatf, replace
ssc install mat2txt, replace			// transforms matrix in txt or xls files
ssc install tabstatmat, replace		// saves tables of statistcs as matrices
ssc install ineqdeco, replace			// Performs inequality indicators and stores them i memory
ssc install inequal7, replace	
*/



/* ---------------	-1-	STARTING A DO FILE	----------------- */		 
				************************

*	-a-	GENERAL SETTINGS
clear
*clear matrix			// erease the * if you work with Stata11 or superior
set more off
set mem 100m
set matsize 500
capture log close
log using do_first.log, replace
program drop _all

*	-b-	CHANGE FOLDER
pwd
cd ..\data_files
pwd
dir
cd ..
cd do_files
dir
*ssc install outreg


*	-c-	UPLOAD DATA DIRECTLY FROM THE DO-FILE
range id 1 10000 10000
gen i = uniform()
gen z = invnormal(i)				//random number generator method to get 10000 observations of a variable z distributed as a standard normal
drawnorm x, n(10000) mean(0) sd(1)		//a faster way to get the same result. The previous method is more flexible
clear

input id y x 
1 3 4.5
2 1 3
3 5 .
4 10 1
end							//manual imputation of 3 variables and 4 observation, you can paste tab separated values
clear


*	-d-	USE AND CHECK DATA
insheet using ..\data_files\smallPSELL.csv
clear
insheet using ..\data_files\smallPSELL.txt, clear
use ..\data_files\smallPSELL.dta, clear
describe
codebook
duplicates report hid
sort hid




/* ---------------	-2-	MODIFY AND LABEL VARIBLES	----------------- */		 
				*******************************


label var hid "Household id"

tab gender_hh
label define sex 1 "M" 2 "F"
label values gender_hh sex

label define natio2 1 "Luxemburg" 2 "Portugal" 3 "Other EU-15" 4 "Not EU-15"
label values natio_hh natio2

rename netinc Y

gen Ypc= Y/size				
gen Ypceq=Y/eqsize 
gen lnY=ln(Y) if Y>0
label var Ypc "Net income per capita in household" 
label var Ypceq "Net income per capita in equivalent household" 
label var lnY "Log of family net income"

gen dhh=size
recode dhh (1=1) (2=2) (3/99=3)
label define dhh1 1 "Single person hh, dummy" 2 "Couple hh, dummy" 3 "couple with children, dummy"
label values dhh dhh1
tab dhh, gen(dhh)
drop dhh2

gen european=1 if (natio_hh==1 | natio_hh==2 | natio_hh==3)
recode european (.=0) 
gen age2=age_hh
recode age2 (0/29 = 1) (30/49 = 2) (50/69 = 3) (70/999 = 4)
label var age2 "Age classes "
label define age2 1 "0-29" 2 "30-49" 3 "50-69" 4 "70+"
label values age2 age2
tab age2, gen(age2_)					//generate 4 dummies valued 1 for each corresponding class of age2 and 0 otherwise
gen age5 = (age2<=50) 		//generate a dummy = 1 if age < or = to 50, 0 otherwise or if age is missing
drop age5




/* ---------------	-3-	STATISTICS		----------------- */		 
				****************

*	-a-	 CONTINUOUS VARIBLES

sum Y, detail
sum Ypc, detail
sum Ypceq, detail
sum Y
ci Y, l(90)
ci Y, l(95)
sum Ypc if (age_hh<50 & gender_hh==1)
bysort gender_hh: sum Ypc, det
bysort gender_hh: ci Ypc, l(95)
ttest Ypc, by(gender_hh) l(95)
ttest Ypc, by(gender_hh) unequal l(95)
ttest Ypc==Ypceq if gender_hh==1
ttest Ypc==Ypceq if gender_hh==2
 
bysort age2: sum Ypceq, det
bysort age2: ci Ypceq, l(95)				
recode age2 (1/2 = 1) (3 = 2) (4 = .) if gender_hh==1, gen(age3)
ttest Ypc, by(age3) unequal l(95)			//test that young man hh has the same income of less young hh

pctile pt1=Y, nq(10)					// gives you deciles
xtile pt2 = Ypc, nq(10)					// provide the interdecile interval of the observation  
xtile pt3 = Ypceq, nq(10)
gen position=1 if pt2<pt3
replace position=2 if pt2==pt3
recode position (.=3) 
xtile pt4 = Ypceq, nq(2)
ttest Ypc, by(pt4) unequal l(95)			// tests equality of average income for those above and those below the median 
sdtest Ypc == Ypceq					// tests equality in income distribution, as captured by the sd
sdtest Ypc, by(pt4) l(95)

table pt4, c(mean Ypceq mean Ypc)			// tabulate some statistics of the variables
table pt4, c(mean Ypceq sd Ypceq p25 Ypceq p75 Ypceq) format(%9.2f)
table pt3, c(mean Ypceq sd Ypceq p25 Ypceq p75 Ypceq) format(%9.2f)
table age2 gender_hh, c(n Ypceq mean Ypceq) format(%9.2f)  

tabstat Y Ypc Ypceq age_hh, stats(n mean sd cv sk k q iqr) by(gender_hh) f(%7.2f) long col(stat) save 	//use save option to export the content of the table as a matrix
tabstatmat sum_stat 		// Stata saves the table results as the matrix named "sum_stat". Is is stored in memory and you will be able to use it later on


*	-b-	 DISCRETE VARIABLES
tab age2
tab age2, nof
tab age2 natio_hh, cell col row nof
tab age2 natio_hh if gender_hh==1, cell
tab size age2, chi2

tab1 age2 natio_hh gender_hh
tab2 age2 natio_hh gender_hh




/* ---------------	-4-	GRAPHING	----------------- */		 
				**************

corr Y age_hh
corr Ypceq age_hh
bysort age2: corr Ypceq age_hh 

	//set local characteristics of each graph
local gropts  "plotregion(style(none) color(white)) graphregion(style(none) color(white)) xsize(3) ysize(3) scheme(s1color)"
local line1 "lpattern(solid) lcolor("51 0 102") lwidth(thick)"
local line2 "lpattern(dash)  lcolor("152 102 204") lwidth(thick)"

hist Y, `gropts' bin(10)
hist Ypceq, `gropts' bin(10) kden norm frac by(gender_hh)  		//histograms by gender

plot Ypceq age_hh
twoway scatter Ypceq age_hh, `gropts'
twoway (lfitci Ypceq age_hh) (scatter Ypceq age_hh ) ,`gropts' 
twoway (scatter Ypceq age_hh) (lfit Ypceq age_hh if gender_hh==1, `line1' ) (lfit Ypceq age_hh if gender_hh==2, `line2'), `gropts'
twoway (scatter Ypceq age_hh) (lfit Ypceq age_hh), by(gender_hh) `gropts'  
graph save ..\output\model.gph, replace





/* ---------------	-5-	REGRESSION ANALYSIS	----------------- */		 
				*************************

reg Ypceq gender_hh
reg Ypceq gender_hh dhh*
bysort pt4: reg Ypceq gender_hh dhh* age2_*, rob
recode pt4 (2=0)
probit pt4 age_hh dhh* gender_hh
logit pt4 age_hh dhh* gender_hh

char gender_hh[omit] 1
xi, pre(D_): reg Ypceq i.gender_hh, rob					//xi: generates dummy variables in the regression, with prefix D_
xi, pre(D_): reg Ypceq age_hh i.gender_hh, rob
xi, pre(D_): reg Ypceq  i.gender_hh*age_hh, rob
test D_gender_hh_2=age_hh=0
xi, pre(D_): mlogit pt4 Ypceq  i.gender_hh*age_hh, rob
char dhh[omit] 2
xi, pre(D_): reg Ypceq i.dhh i.gender_hh age_hh, rob
test D_dhh_1 = D_dhh_3 = 0
xi, pre(D_): reg Ypceq dhh* i.gender_hh age_hh, rob
test dhh1=dhh3=0
*testnl (_b[dhh1]/_b[dhh3] = _b[age_hh]) (_b[age_hh] = 1)
cd ../output/
outreg2 using model.txt, bdec(3) se replace tex(fragment) 
xi, pre(D_): reg Ypceq i.dhh i.gender_hh age_hh if natio_hh==3, rob
outreg2 using model.txt,  bdec(3) tex(fragment) se append 
cd ../do_files
*	- a -   	RESULTS IN A TABLE

reg Y age2_1 age2_2 age2_4 size
estimates store m1, title(Model 1)
reg Y size
estimates store m2, title(Model 2)
local estout_opt1 "cells(b(star fmt(%9.3f)) se(par))  stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared)) legend label collabels(, none)  varlabels(_cons Constant) posthead("")  prefoot("") postfoot("")  varwidth(16) modelwidth(12) delimiter("")"
local estout_opt2 "cells(b(star fmt(%9.3f)) se(par))  stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared)) legend label collabels(, none)  varlabels(_cons Constant) posthead("")  prefoot("") postfoot("")  varwidth(16) modelwidth(12)  sty(tex)"
estout m1 m2 , `estout_opt1'    		// a table as it appears in papers 
estout m1 m2 , `estout_opt2'			// ready for latex!



*	- b - 	POST ESTIMATION

predict e if natio_hh==3, res					// predictions, usually identified by a "hat" in textbooks
predict xb if natio==3
twoway scatter e xb if natio==3, `gropts'

sktest e 
ttest e=0
kdensity e, norm `gropts'





/* ---------------	-6-	SAVING AND CLOSING	----------------- */		 
				************************


save ../data_files/smallPSELL2.dta, replace
outsheet using ../data_files/smallPSELL2.txt, replace
outfile using ../data_files/smallPSELL2.csv, dictionary replace
outsheet e xb using ../data_files/estimates.txt if natio_hh==3, replace




/* ---------------	-7.1-	PROGRAMMING WITH DATA	----------------- */		 
				***************************

* This section is meant to provide a soft introduction to programming via examples.
* Some examples are easy, some other sensless, and some other are more complex and need some theoretical background to be inderstood.
* The main issue is to introduce you to the use of programming your own commands.

local a "10"
local b "7 + (2+1)"
local c  = "7 + (2+1)"
di 3
di 3+3 
di "a"
di `a' + 1
di 10/`a'
di 7/`b'
di 7/(`b')
di 7/`c'


*	- a -		Use locals to avoid risk of errors when repeating some variables
 
local control "age2* gender_hh"
local condition "age_hh>=40"
reg Y size `control' if `condition'


*	- b -		Use a loop to perform the same linear regression over many dependent vairables,
*			using always the same controls/conditions

foreach x in Y Ypc lnY {
reg `x' size `control' if `condition'
estimates store mod`x', title (Dep Var `x')
}
estout mod*, `estout_opt1'



*	- c -		Easy program: TABLE OF SAMPLE MEAN AND SD FOR SOME VARIABLES

capture program drop table2
program define table2
	version 8
	syntax varlist [if] [, title(string)]
	display as error
	if "`title'" != "" {
		display "`title': "
	}
	display as text %9s "	" %9s "Mean" %9s "	" %9s "Sd" 
	foreach x of local varlist {
		quietly sum `x' `if'
		display %9s "`x'" "	" %9.0g r(mean) "	" %9.0g r(sd)
	}
end

table2 Y
table2 Y lnY if size==1, title(Income and log Income of couples) 



*	- d -		LINEAR REGRESSION ESTIMATION BY ML

* Use ml, the maximum likelihood command in Stata, to derive coefficients from a linear model,
* with errors assumed normally distributed with zero mean s2 variance.
* The model estimates "Theta1" as a linear model on 2 variables and 3 coefficients, 
* and "theta2" as the standard deviation of residuals ((RSS/(N-k))^0.5). 
* We use "lf" option because of the linearity of the model. The output will resemble to a two equation estimation
* Finally, we test under normality the equality between the standard deviation of (corrected) residuals and sigma, the ml sd under normality.
 
capture program drop mlreg 
program define mlreg
	version 8
	args lnf theta1 theta2
	quietly replace `lnf' = ln(normd(($ML_y1 - `theta1')/`theta2')) - ln(`theta2')
end
ml model lf mlreg (lnY = size age_hh) /sigma			//You are regressing lnY on two controls and estimate sigma as a constant
ml maximize

matrix list e(b)
display _b[sigma:_cons]
local sigma_ml = _b[sigma:_cons]					// save sigma in a local as a scalar value
macro list 

* Now using the last estimates, we compare the result to sigma_ml:
reg lnY size age_hh
predict e_hat, res
replace e_hat = e_hat*((e(N)-1)/(e(df_r)))^.5			// residual of the linear model corrected for the df of the model
sdtest e_hat == `sigma_ml'						// F-test on sd of the residuals: we cannot reject the null.

di (e(rss)/e(df_r))^.5							// Another way to determine sd of residuals





*	- e -		SEGREGATION CURVES

* The segregation curve aims at evaluating the degree of evenness in the distribution
* of two groups across a reference partition. When using size2, we compare the distribution 
* of young hh with and without children across income quantiles.
* A priori, we expect the distribution being even, but the segregation courve will tell us a different story 
* Segregation courve can be read as a Lorenz courve, and literature has derived implications of the "segregation ordering"
* We write a program "segcurve" providing the coordinates of the segregation courve for diffent variables, 
* and reporting the coordinates directly in the original dataset: segregation courve can be therefore plotted as a graph.
* Firstly we contruct a variable for partition for each observation. 
* Then, we contruct the reference dummy variables defining the populations of interest (size2, size3). Each observation in the population
* belongs to group 0 (if the variable takes value 0) or 1 (it the variable takes value 1).
* Next, we contruct the program named "segcurve", by using "program ... end". Stata memorize in segcurve the list of operations defined by the program.
* Note that the program would work with any possible set of variables, returning the segregation curve coordinates for each population
* The syntax of the program is: "segcurve partition_var varlist"
* Finally, we run the program with our variables. Then, we graph the curve. The small numbers in the graph state for the quintile.
* You have all the means to understand the structure of the program. It could be rewritte in a less friendly style by using "mata" notation.
* Moreover, once you get the coordinates of the Segregation Curve, you can calculate segregation indices. 

xtile partition = Ypceq, nq(5)				// partition, quintiles of hh income
gen size2 = (size<=2) if age_hh<55				// two groups for young population: 1 for households made by singles or couples, 0 if children
gen size3 = (size<=2) if age_hh>= 55			// two groups for old population:	1 for households made by singles or couples, 0 if children
local label_var_size2 "Under 55"
local label_var_size3 "55 + "
local label_val_0 "big hh"
local label_val_1 "small hh"
label var size2 "Under 55"
label var size3 "55 + "


capture program drop segcurve
program define segcurve
	version 8
	syntax varlist(min=2 max=21)
	tokenize `varlist'
            local part `1'
            macro shift
            local varlist `*'
	foreach z of local varlist { 
		forvalues x = 0/1 {
			sum `z' if `z' == `x'
			scalar T`z'_`x' = r(N)
			egen p`x'_`z' = count(`z') if `z' == `x', by(`part')
			sort `part' p`x'_`z'
			by `part': gen n`x'=_n
			sort n`x'
			replace p`x'_`z'=0 if p`x'_`z'==. & n`x'==1
			replace p`x'_`z'=. if n`x'!=1
			replace p`x'_`z'=p`x'_`z'/T`z'_`x'
			gen order=`part'
			replace order=. if n`x'!=1
			sort order
			mkmat order p`x'_`z' , mat(s_`z'_`x') nomissing
			drop order p`x'* n`x'
		}
	}
	quietly tab `part'
	local max_0 = r(r)+1
	matrix zero = (.,0,0,.)									/* A row vector with two missing values */
	foreach z of local varlist {
		svmat s_`z'_0
		svmat s_`z'_1
		gen q_`z' = s_`z'_02/s_`z'_12
		qui sum q_`z'
		qui replace q_`z' = r(max)+1 if s_`z'_12==0
		quietly replace q_`z'= -1 in `max_0' 
		gsort + q_`z'
		replace s_`z'_02 = sum(s_`z'_02)
		replace s_`z'_12 = sum(s_`z'_12)
		mkmat s_`z'_01 s_`z'_02 s_`z'_12 q_`z', mat(s1_`z') nomissing
		matrix s1_`z' = zero\s1_`z'							/* Create a matrix with the first line equal to the matrix zero (for graphing)*/
		drop s_`z'_01 s_`z'_02 s_`z'_12 q_`z'
		}
	local gropts  "ytitle(Cumulative prop. of type 0) ytitle(, color(black)) yscale(range(0 1)) yline(1) ylabel(, grid glcolor(black)) ymtick(0(0.1)1, grid glcolor(black)) xline(1, noextend) xlabel(0(0.1)1) xmtick(0(0.1)1, grid glcolor(black)) title(Segregation Curve) note(Plot of relative distributions of the two groups) legend(position(6) )  plotregion(style(none) color(white)) graphregion(style(none) color(white)) xtitle(Cumulative prop. of type 1) xsize(3) ysize(3) scheme(s1color)"
	local line "lpattern(solid) lwidth(thick)"
	local diagonal "(function y=x, range(0 1) lw(medthick))"
	foreach z of local varlist {
	svmat s1_`z'
	rename s1_`z'2 seg_`z'_0
	rename s1_`z'3 seg_`z'_1
	rename s1_`z'1 label_`z'
	label var seg_`z'_0 "`z'" 
/*	label var seg_`z'_0 "`label_var_`z''" */
	local label_`z' " mlabel(label_`z') msymbol(circle) mlabsize(small) mlabcolor(black) mlabposition(11) connect(direct)"
	twoway (connected seg_`z'_0 seg_`z'_1, `label_`z'' `line' lcolor("51 0 102")) `diagonal' , `gropts' legend(order(- "Population: " 1 ) rows(1))
	}
end
	// The program segcurve gives you the coordinates of the segregation curve in a format which is compatible with data at hand.
	// You can therefore plot the coordinates using the following graph with the options specified in the program.
	// The name of the coordinates of the segregation curves are: seg_"varname"_0 for ordinate and seg_"varname"_1 for the abscisse.


local vars "size2 size3"

segcurve partition `vars'		// The command perform segregation curves coordinates for the variables specified here
 
	// Some labels for graphing the curve 
local gropts  "ytitle(Cumulative prop. of type `label_val_0') ytitle(, color(black)) yscale(range(0 1)) yline(1) ylabel(, grid glcolor(black)) ymtick(0(0.1)1, grid glcolor(black)) xline(1, noextend)  xmtick(0(0.1)1, grid glcolor(black)) title(Segregation Curve) note(Plot of relative distributions of the two groups) legend(position(6) )  plotregion(style(none) color(white)) graphregion(style(none) color(white)) xtitle(Cumulative prop. of type `label_val_1') xsize(3) ysize(3) scheme(s1color)"
local line "lpattern(solid) lwidth(thick)"
foreach z of local vars {
	local label_`z' " mlabel(label_`z') msymbol(circle) mlabsize(small) mlabcolor(black) mlabposition(11) connect(direct)"
}
local diagonal "(function y=x, range(0 1) lw(medthick))"
label var seg_size2_0 "`label_var_size2'"
label var seg_size3_0 "`label_var_size3'"

	// The two curves 
twoway (connected seg_size2_0 seg_size2_1, `label_size2' `line' lcolor("51 0 102")) ///
	 (connected seg_size3_0 seg_size3_1, `label_size3' `line' lcolor(red)) 		///
	 `diagonal' , 											///
	 `gropts' legend(order(- "Populations: " 1 2) rows(1))

	// Finally, the graph of the segregation curves: old hh seems to be more segregated than young households, reflecting more disparities in income distribution.






/* ---------------	-7.2-	PROGRAMMING WITH OUTPUT		----------------- */		 
				*****************************


sum Y, det
scalar m = r(mean)

*		-a-	t-TEST FOR " SUBSAMPLE MEANS EQUALITY.

sum Y if natio_hh==1
scalar m1 = r(mean)
scalar sd1 = r(sd)
scalar n1 = r(N)
sum Y if natio_hh==2
scalar m2 = r(mean)
scalar sd2 = r(sd)
scalar n2 = r(N)
scalar dm=m1-m2
scalar serror=(sd1^2/(n1) + sd2^2/(n2))^.5
scalar ttest=dm/serror
scalar list

recode natio_hh (3/99=.), gen(natio2)
ttest Y, by(natio2) uneq


*		-b-	OLS COEFFICIENTS ESTIMATION AND THEIR VC MATRIX.

reg Y age_hh size 
ereturn list
matrix list e(b)
matrix list e(V)
vce, corr
est tab, stats(N r2) se

scalar s=e(rss)/e(df_r)
gen I=1
mkmat Y, mat(y)
mkmat I age_hh size, mat(X)
mkmat I, mat(I)
matrix Beta = syminv(X'*X)*X'*y  	// OLS beta estimator
matrix VC	= syminv(X'*X)*s		// Standard errors and covariances of OLS beta estimators
matrix list Beta 
matrix list e(b) 
matrix list VC 
matrix list e(V)

matrix list Beta, noname format(%9.2f) nohalf title(Reg. Coefficints)
matrix list VC, noname format(%9.2f) nohalf title(Variance Covariance matrix)

* save a matrix as a .xls file with regression coefficients and VC matrix in a well defined position
matrix C = Beta'\VC
mat2txt, matrix(C) saving(..\output\b_vc_matrix.xls) title(Model Estimates) ///
	note(Beta coeff in the first line. Line 2 to 4 is the VC matrix of Betas.) format(%50.2f) replace




*		-c-	SAVE AND EXPORT INEQUALITY MEASURES AS A TABLE ON A .xls FILE

* We want to compute inequality measures (Gini coefficient, Generalized Entropy Index and Atkinson Index) 
* on the equivalent hh income, Ypceq, and for different classes of age, using age2 as the reference variable. 
* We make use of the ineqdeco command, and we run it for subgroups using the if option.
* Moreover, we would like to obtain for each subgroup the average Ypceq, its sd and the subsample dimension.
* We need to save in a .xls file a table with mean, sd and inequality indices by row (for a total of 6 rows),
* according to the age classes, by columns (for a total of 4 columns)
* Firstly, we use a loop to obtain summary statisticas and indices of the variable Ypceq for all values of age2
* For each class, we store in memory the statistics and indices as a column vector ordered as " (mean\ sd\ N\ Gini\ GE\ Atkinson)' "
* We do that for all the 4 classes of age2, obtaining 4 column vectors.
* Then, we generate a new matrix called "inequality" made up by 6 lines and 4 columns.
* Finally, we export the matrix in the \output folder as an excell file, under the name of "inequality.xls". 
* We make use of the application "mat2txt" which you can download from ssc.
* Take care that it is strictly necessary to use iequality (or other) commands that admit the "return" or the "ereturn".
* Check in the help file that results can be stored in "r()" or "e()" format, respectively.

forvalues x = 1/4 {
	quietly{
		local if "if age2==`x'"
		sum Ypceq `if'
		matrix inequality_`x' = (r(mean), r(sd), r(N))
		ineqdeco Ypceq `if'		
		matrix inequality_`x' = (inequality_`x', r(gini), r(ge2), r(a2) )'
		matrix colnames inequality_`x' =  Age_group_`x'
		matrix rownames inequality_`x' = Mean Sd N Gini GE Atkinson 
	}
}
matrix inequality = (inequality_1, inequality_2, inequality_3, inequality_4)
mat2txt, matrix(inequality) saving(..\output\inequality.xls) title(Inequality in equivalent income, for age groups) ///
	 note(By column: age groups.) format(%50.2f) replace






*end
*close
capture log close


